/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.test;

import java.io.IOException;
import java.io.PrintWriter;

import javax.ejb.EJB;
import javax.naming.NamingException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.jboss.test.ejb.Hello;

/**
 * 
 * @author Josef Cacek
 */
public abstract class AbstractRunAsServlet extends HttpServlet {

    private static final long serialVersionUID = 1L;

    @EJB
    Hello ejb;

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        resp.setContentType("text/plain");
        PrintWriter writer = resp.getWriter();
        try {
            writer.print(callProtectedEJB());
        } catch (Exception e) {
            e.printStackTrace(writer);
        }
    }

    @Override
    public void destroy() {
        try {
            callProtectedEJB();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public void init() throws ServletException {
        try {
            callProtectedEJB();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private String callProtectedEJB() throws NamingException {
        // InitialContext context = new InitialContext();
        // ProtectedEJB ejb = (ProtectedEJB) context.lookup("java:global/secured-webapp/" + HelloBean.class.getSimpleName()
        // + "!" + Hello.class.getName());
        StackTraceElement stackTraceElement = new Exception().getStackTrace()[1];
        System.out.println(">>> " + getClass().getName() + "." + stackTraceElement.getMethodName() + "()");
        String hello = ejb.sayHello();
        System.out.println(">>> " + hello);
        return hello;
    }

}
